@@ -47,8 +47,8 @@ int              gsd_power_backlight_abs_to_percentage  (int min, int max, int v
 int              gsd_power_backlight_percentage_to_abs  (int min, int max, int value);
 
 /* RandR helpers */
-void             watch_external_monitor                 (GnomeRRScreen *screen);
-gboolean         external_monitor_is_connected          (GnomeRRScreen *screen);
+void             watch_external_monitor                 (void);
+gboolean         external_monitor_is_connected          (void);
 
 /* Sound helpers */
 void             play_loop_start                        (guint *id);
