@@ -24,17 +24,14 @@
 #include <glib.h>
 #include <gio/gio.h>
 
-#define GNOME_DESKTOP_USE_UNSTABLE_API
-#include <libgnome-desktop/gnome-rr.h>
-
-
 G_BEGIN_DECLS
 
 #define GSD_TYPE_BACKLIGHT gsd_backlight_get_type ()
 G_DECLARE_FINAL_TYPE (GsdBacklight, gsd_backlight, GSD, BACKLIGHT, GObject);
 
-gint gsd_backlight_get_brightness        (GsdBacklight         *backlight,
-                                          gint                 *target);
+gint gsd_backlight_get_brightness        (GsdBacklight         *backlight);
+
+gint gsd_backlight_get_target_brightness (GsdBacklight         *backlight);
 
 void gsd_backlight_set_brightness_async  (GsdBacklight         *backlight,
                                           gint                  percentage,
@@ -72,8 +69,7 @@ gint gsd_backlight_cycle_up_finish       (GsdBacklight         *backlight,
 
 const char*  gsd_backlight_get_connector (GsdBacklight         *backlight);
 
-GsdBacklight* gsd_backlight_new          (GnomeRRScreen        *screen,
-                                          GError              **error);
+GsdBacklight* gsd_backlight_new          (GError              **error);
 
 
 G_END_DECLS
