@@ -119,7 +119,7 @@ class PowerPluginBase(gsdtestcase.GSDTestCase):
 
         # start mock power-profiles-daemon
         try:
-            (self.ppd, self.obj_ppd) = self.spawn_server_template('power_profiles_daemon')
+            (self.ppd, self.obj_ppd) = self.spawn_server_template('upower_power_profiles_daemon')
             self.addCleanup(self.stop_process, self.ppd)
         except ModuleNotFoundError:
             self.ppd = None
@@ -783,7 +783,7 @@ class PowerPluginTestBatteryLevels(PowerPluginBase):
         # Check that it was picked up
         self.check_plugin_log('EMIT: charge-critical', 2)
 
-        self.p_notify_log.check_line_re(rb'[0-9.]+ Notify "Power" .* "battery-caution-symbolic" ".*[Bb]attery [Aa]lmost [Ee]mpty.*"', timeout=0.5)
+        self.p_notify_log.check_line_re(rb'[0-9.]+ Notify "Power" .* "" ".*[Bb]attery [Aa]lmost [Ee]mpty.*"', timeout=0.5)
 
     def test_notify_critical_battery_on_start(self):
         '''action on critical battery on startup'''
@@ -793,7 +793,7 @@ class PowerPluginTestBatteryLevels(PowerPluginBase):
         # Check that it was picked up
         self.check_plugin_log('EMIT: charge-critical', 2)
 
-        self.p_notify_log.check_line_re(rb'[0-9.]+ Notify "Power" .* "battery-caution-symbolic" ".*[Bb]attery [Aa]lmost [Ee]mpty.*"', timeout=0.5)
+        self.p_notify_log.check_line_re(rb'[0-9.]+ Notify "Power" .* "" ".*[Bb]attery [Aa]lmost [Ee]mpty.*"', timeout=0.5)
 
     def test_notify_device_battery(self):
         '''critical power level notification for device batteries'''
@@ -987,7 +987,7 @@ class PowerPluginTestBatteryLevels(PowerPluginBase):
 
         self.check_for_logout(idle_delay + 2)
 
-        self.p_notify_log.check_line(b'You will soon log out because of inactivity.')
+        self.p_notify_log.check_line(b'You will soon log out because of inactivity')
 
     def test_forced_logout_inhibition(self):
         '''Test we don't force logout when inhibited'''
@@ -1291,19 +1291,19 @@ class PowerPluginTestBrightnessStep(PowerPluginBase):
 
         self.set_composite_battery_discharging()
         time.sleep(0.5)
-        holds = obj_props.Get('net.hadess.PowerProfiles', 'ActiveProfileHolds')
+        holds = obj_props.Get('org.freedesktop.UPower.PowerProfiles', 'ActiveProfileHolds')
         self.assertEqual(len(holds), 0)
 
         self.set_composite_battery_critical()
         time.sleep(0.5)
-        holds = obj_props.Get('net.hadess.PowerProfiles', 'ActiveProfileHolds')
+        holds = obj_props.Get('org.freedesktop.UPower.PowerProfiles', 'ActiveProfileHolds')
         self.assertEqual(len(holds), 1)
         self.assertEqual(holds[0]['Profile'], 'power-saver')
         self.assertEqual(holds[0]['ApplicationId'], 'org.gnome.SettingsDaemon.Power')
 
         self.set_composite_battery_discharging()
         time.sleep(0.5)
-        holds = obj_props.Get('net.hadess.PowerProfiles', 'ActiveProfileHolds')
+        holds = obj_props.Get('org.freedesktop.UPower.PowerProfiles', 'ActiveProfileHolds')
         self.assertEqual(len(holds), 0)
 
 # avoid writing to stderr
